GEO_URLS = {
    'tracts': {
        2000: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2000/MapServer/8',
        2010: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/14',
        2011: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/14',
        2012: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/14',
        2013: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2013/MapServer/8',
        2014: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2014/MapServer/8',
        2015: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2015/MapServer/8',
        2016: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2016/MapServer/8',
        2017: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2017/MapServer/8',
        2018: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2018/MapServer/8',
        2019: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2019/MapServer/8',
        2020: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2020/MapServer/6',
        2021: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2021/MapServer/6',
        2022: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2022/MapServer/6',
        2023: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2023/MapServer/8',
    },
    'block groups': {
        2000: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2000/MapServer/10',
        2010: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/16',
        2011: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/16',
        2012: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/16',
        2013: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2013/MapServer/10',
        2014: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2014/MapServer/10',
        2015: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2015/MapServer/10',
        2016: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2016/MapServer/10',
        2017: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2017/MapServer/10',
        2018: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2017/MapServer/10',
        2019: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2018/MapServer/10',
        2020: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2020/MapServer/8',
        2021: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2021/MapServer/8',
        2022: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2022/MapServer/8',
        2023: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2023/MapServer/10',
    },
    'blocks': {
        2000: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2000/MapServer/12',
        2010: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2010/MapServer/14',
        2020: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2020/MapServer/10',
    },
    'incorporated places': {
        2000: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2000/MapServer/26',
        2010: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/34',
        2011: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/34',
        2012: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_Census2010/MapServer/34',
        2013: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2013/MapServer/26',
        2014: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2014/MapServer/26',
        2015: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2015/MapServer/26',
        2016: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2016/MapServer/26',
        2017: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2017/MapServer/26',
        2018: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2018/MapServer/26',
        2019: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2019/MapServer/26',
        2020: 'https://tigerweb.geo.census.gov/arcgis/rest/services/Census2020/tigerWMS_Census2020/MapServer/26',
        2021: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2021/MapServer/24',
        2022: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2022/MapServer/24',
        2023: 'https://tigerweb.geo.census.gov/arcgis/rest/services/TIGERweb/tigerWMS_ACS2023/MapServer/28',
    },
}

LODES_VARIABLES = {
    "id": "Census Block code - 15 character nationally unique identifier",
    "c000": "Total number of jobs",
    "ca01": "Number of jobs of workers age 29 or younger",
    "ca02": "Number of jobs for workers age 30 to 54",
    "ca03": "Number of jobs for workers age 55 or older",
    "ce01": "Number of jobs with earnings $1250/month or less",
    "ce02": "Number of jobs with earnings $1251/month to $3333/month",
    "ce03": "Number of jobs with earnings greater than $3333/month",
    "cns01": "Number of jobs in NAICS sector 11 (Agriculture, Forestry, Fishing and Hunting)",
    "cns02": "Number of jobs in NAICS sector 21 (Mining, Quarrying, and Oil and Gas Extraction)",
    "cns03": "Number of jobs in NAICS sector 22 (Utilities)",
    "cns04": "Number of jobs in NAICS sector 23 (Construction)",
    "cns05": "Number of jobs in NAICS sector 31-33 (Manufacturing)",
    "cns06": "Number of jobs in NAICS sector 42 (Wholesale Trade)",
    "cns07": "Number of jobs in NAICS sector 44-45 (Retail Trade)",
    "cns08": "Number of jobs in NAICS sector 48-49 (Transportation and Warehousing)",
    "cns09": "Number of jobs in NAICS sector 51 (Information)",
    "cns10": "Number of jobs in NAICS sector 52 (Finance and Insurance)",
    "cns11": "Number of jobs in NAICS sector 53 (Real Estate and Rental and Leasing)",
    "cns12": "Number of jobs in NAICS sector 54 (Professional, Scientific, and Technical Services)",
    "cns13": "Number of jobs in NAICS sector 55 (Management of Companies and Enterprises)",
    "cns14": "Number of jobs in NAICS sector 56 (Administrative and Support and Waste Management and Remediation Services)",
    "cns15": "Number of jobs in NAICS sector 61 (Educational Services)",
    "cns16": "Number of jobs in NAICS sector 62 (Health Care and Social Assistance)",
    "cns17": "Number of jobs in NAICS sector 71 (Arts, Entertainment, and Recreation)",
    "cns18": "Number of jobs in NAICS sector 72 (Accommodation and Food Services)",
    "cns19": "Number of jobs in NAICS sector 81 (Other Services [except Public Administration])",
    "cns20": "Number of jobs in NAICS sector 92 (Public Administration)",
    "cr01": "Number of jobs of workers, Race: White Alone",
    "cr02": "Number of jobs of workers, Race: Black or African American Alone ",
    "cr03": "Number of jobs of workers, Race: American Indian or Alaska Native Alone",
    "cr04": "Number of jobs of workers, Race: Asian Alone",
    "cr05": "Number of jobs of workers, Race: Native Hawaiian or Other Pacific Islander Alone",
    "cr07": "Number of jobs of workers, Race: Two or More Race Groups",
    "ct01": "Number of jobs of workers, Ethnicity: Not Hispanic or Latino",
    "ct02": "Number of jobs of workers, Ethnicity: Hispanic or Latino",
    "cd01": "Number of jobs of workers, Educational Attainment: Less than high school",
    "cd02": "Number of jobs of workers, Educational Attainment: High school or equivalent, no college",
    "cd03": "Number of jobs of workers, Educational Attainment: Some college or Associate degree",
    "cd04": "Number of jobs of workers, Educational Attainment: Bachelor's degree or advanced degree",
    "cg01": "Number of jobs of workers, Sex: Male",
    "cg02": "Number of jobs of workers, Sex: Female",
    "cfa01": "Number of jobs of workers, Firm Age: 0-1 Years",
    "cfa02": "Number of jobs of workers, Firm Age: 2-3 Years",
    "cfa03": "Number of jobs of workers, Firm Age: 4-5 Years",
    "cfa04": "Number of jobs of workers, Firm Age: 6-10 Years",
    "cfa05": "Number of jobs of workers, Firm Age: 11+ Years",
    "cfs01": "Number of jobs of workers, Firm Size: 0-19 Employees",
    "cfs02": "Number of jobs of workers, Firm Size: 20-49 Employees",
    "cfs03": "Number of jobs of workers, Firm Size: 50-249 Employees",
    "cfs04": "Number of jobs of workers, Firm Size: 250-499 Employees",
    "cfs05": "Number of jobs of workers, Firm Size: 500+ Employees"
}
